<?php
/**
 * Version informations about ssh2 extension
 *
 * PHP version 5
 *
 * @category PHP
 * @package  PHP_CompatInfo
 * @author   Laurent Laville <pear@laurent-laville.org>
 * @license  http://www.opensource.org/licenses/bsd-license.php  BSD License
 * @version  SVN: $Id$
 * @link     http://php5.laurent-laville.org/compatinfo/
 */

/**
 * All interfaces, classes, functions, constants about ssh2 extension
 *
 * @category PHP
 * @package  PHP_CompatInfo
 * @author   Laurent Laville <pear@laurent-laville.org>
 * @license  http://www.opensource.org/licenses/bsd-license.php  BSD License
 * @version  Release: 2.5.0
 * @link     http://php5.laurent-laville.org/compatinfo/
 * @link     http://www.php.net/manual/en/book.ssh2.php
 */
class PHP_CompatInfo_Reference_Ssh2 implements PHP_CompatInfo_Reference
{
    /**
     * Gets all informations at once about:
     * extensions, interfaces, classes, functions, constants
     *
     * @param string $extension OPTIONAL
     * @param string $version   OPTIONAL PHP version
     *                          (4 => only PHP4, 5 or null => PHP4 + PHP5)
     *
     * @return array
     */
    public function getAll($extension = null, $version = null)
    {
        $references = array(
            'extensions' => $this->getExtensions($extension, $version),
            'interfaces' => $this->getInterfaces($extension, $version),
            'classes'    => $this->getClasses($extension, $version),
            'functions'  => $this->getFunctions($extension, $version),
            'constants'  => $this->getConstants($extension, $version),
        );
        return $references;
    }

    /**
     * Gets informations about extensions
     *
     * @param string $extension OPTIONAL
     * @param string $version   OPTIONAL PHP version
     *                          (4 => only PHP4, 5 or null => PHP4 + PHP5)
     *
     * @return array
     */
    public function getExtensions($extension = null, $version = null)
    {
        $extensions = array(
            'ssh2' => array('5.0.0', '', '0.11.0')
        );
        return $extensions;
    }

    /**
     * Gets informations about interfaces
     *
     * @param string $extension OPTIONAL
     * @param string $version   OPTIONAL PHP version
     *                          (4 => only PHP4, 5 or null => PHP4 + PHP5)
     *
     * @return array
     */
    public function getInterfaces($extension = null, $version = null)
    {
        $interfaces = array();

        if ((null == $version ) || ('4' == $version)) {
            $version4 = array(
            );
            $interfaces = array_merge(
                $interfaces,
                $version4
            );
        }
        if ((null == $version ) || ('5' == $version)) {
            $version5 = array(
            );
            $interfaces = array_merge(
                $interfaces,
                $version5
            );
        }
        return $interfaces;
    }

    /**
     * Gets informations about classes
     *
     * @param string $extension OPTIONAL
     * @param string $version   OPTIONAL PHP version
     *                          (4 => only PHP4, 5 or null => PHP4 + PHP5)
     *
     * @return array
     */
    public function getClasses($extension = null, $version = null)
    {
        $classes = array();

        if ((null == $version ) || ('4' == $version)) {
            $version4 = array(
            );
            $classes = array_merge(
                $classes,
                $version4
            );
        }
        if ((null == $version ) || ('5' == $version)) {
            $version5 = array(
            );
            $classes = array_merge(
                $classes,
                $version5
            );
        }

        return $classes;
    }

    /**
     * Gets informations about functions
     *
     * @param string $extension OPTIONAL
     * @param string $version   OPTIONAL PHP version
     *                          (4 => only PHP4, 5 or null => PHP4 + PHP5)
     *
     * @return array
     * @link   http://www.php.net/manual/en/ref.ssh2.php
     */
    public function getFunctions($extension = null, $version = null)
    {
        $functions = array();

        if ((null == $version ) || ('4' == $version)) {
            $version4 = array(
                'ssh2_auth_hostbased_file'       => array('5.0.0', ''),
                'ssh2_auth_none'                 => array('5.0.0', ''),
                'ssh2_auth_password'             => array('5.0.0', ''),
                'ssh2_auth_pubkey_file'          => array('5.0.0', ''),
                'ssh2_connect'                   => array('5.0.0', ''),
                'ssh2_exec'                      => array('5.0.0', ''),
                'ssh2_fetch_stream'              => array('5.0.0', ''),
                'ssh2_fingerprint'               => array('5.0.0', ''),
                'ssh2_forward_accept'            => array('5.0.0', ''),
                'ssh2_forward_listen'            => array('5.0.0', ''),
                'ssh2_methods_negotiated'        => array('5.0.0', ''),
                'ssh2_poll'                      => array('5.0.0', ''),
                'ssh2_publickey_add'             => array('5.0.0', ''),
                'ssh2_publickey_init'            => array('5.0.0', ''),
                'ssh2_publickey_list'            => array('5.0.0', ''),
                'ssh2_publickey_remove'          => array('5.0.0', ''),
                'ssh2_scp_recv'                  => array('5.0.0', ''),
                'ssh2_scp_send'                  => array('5.0.0', ''),
                'ssh2_sftp_lstat'                => array('5.0.0', ''),
                'ssh2_sftp_mkdir'                => array('5.0.0', ''),
                'ssh2_sftp_readlink'             => array('5.0.0', ''),
                'ssh2_sftp_realpath'             => array('5.0.0', ''),
                'ssh2_sftp_rename'               => array('5.0.0', ''),
                'ssh2_sftp_rmdir'                => array('5.0.0', ''),
                'ssh2_sftp_stat'                 => array('5.0.0', ''),
                'ssh2_sftp_symlink'              => array('5.0.0', ''),
                'ssh2_sftp_unlink'               => array('5.0.0', ''),
                'ssh2_sftp'                      => array('5.0.0', ''),
                'ssh2_shell'                     => array('5.0.0', ''),
                'ssh2_tunnel'                    => array('5.0.0', ''),
            );
            $functions = array_merge(
                $functions,
                $version4
            );
        }
        if ((null == $version ) || ('5' == $version)) {
            $version5 = array(
            );
            $functions = array_merge(
                $functions,
                $version5
            );
        }
        return $functions;
    }

    /**
     * Gets informations about constants
     *
     * @param string $extension OPTIONAL
     * @param string $version   OPTIONAL PHP version
     *                          (4 => only PHP4, 5 or null => PHP4 + PHP5)
     *
     * @return array
     * @link   http://www.php.net/manual/en/ssh2.constants.php
     */
    public function getConstants($extension = null, $version = null)
    {
        $constants = array();

        if ((null == $version ) || ('4' == $version)) {
            $version4 = array(
            );
            $constants = array_merge(
                $constants,
                $version4
            );
        }
        if ((null == $version ) || ('5' == $version)) {
            $version5 = array(
                'SSH2_FINGERPRINT_MD5'              => array('5.0.0', ''),
                'SSH2_FINGERPRINT_SHA1'             => array('5.0.0', ''),
                'SSH2_FINGERPRINT_HEX'              => array('5.0.0', ''),
                'SSH2_FINGERPRINT_RAW'              => array('5.0.0', ''),
                'SSH2_TERM_UNIT_CHARS'              => array('5.0.0', ''),
                'SSH2_TERM_UNIT_PIXELS'             => array('5.0.0', ''),
                'SSH2_DEFAULT_TERMINAL'             => array('5.0.0', ''),
                'SSH2_DEFAULT_TERM_WIDTH'           => array('5.0.0', ''),
                'SSH2_DEFAULT_TERM_HEIGHT'          => array('5.0.0', ''),
                'SSH2_DEFAULT_TERM_UNIT'            => array('5.0.0', ''),
                'SSH2_STREAM_STDIO'                 => array('5.0.0', ''),
                'SSH2_STREAM_STDERR'                => array('5.0.0', ''),
                'SSH2_POLLIN'                       => array('5.0.0', ''),
                'SSH2_POLLEXT'                      => array('5.0.0', ''),
                'SSH2_POLLOUT'                      => array('5.0.0', ''),
                'SSH2_POLLERR'                      => array('5.0.0', ''),
                'SSH2_POLLHUP'                      => array('5.0.0', ''),
                'SSH2_POLLNVAL'                     => array('5.0.0', ''),
                'SSH2_POLL_SESSION_CLOSED'          => array('5.0.0', ''),
                'SSH2_POLL_CHANNEL_CLOSED'          => array('5.0.0', ''),
                'SSH2_POLL_LISTENER_CLOSED'         => array('5.0.0', ''),
            );
            $constants = array_merge(
                $constants,
                $version5
            );
        }

        return $constants;
    }

}
